Interface used to interact with a Dualsense controller; encapsulates
a hidapi::HidDevice and a buffer to be re-used when reading input
reports from the hid device.
Estimates Tilt given sample readings; it keeps state pertaining the
previous readings and estimates to implement an algorighm similar
to the one described here
Configuration for a crate::TiltEstimator; the SAMPLES constant will determine
how big a buffer of accelerometer readings to keep in order to compute
the accelerometer’s average over time.