Dualsense

Struct Dualsense 

pub struct Dualsense { /* private fields */ }
Interface used to interact with a Dualsense controller; encapsulates a hidapi::HidDevice and a buffer to be re-used when reading input reports from the hid device.

Implementations

Source

impl Dualsense

pub fn new(hid_api: &mut HidApi) -> HidResult<Dualsense>

Creates a new Dualsense instance; will error if no device is connected to the USB port.

pub fn read_into(&mut self, state: &mut DualsenseState) -> HidResult<()>

Reads an input report from the device into a provided mutable reference to a gamepad state.

pub fn read(&mut self) -> HidResult<DualsenseState>

Reads an input report from the device and returns a gamepad state.