TiltEstimatorConfig

Struct TiltEstimatorConfig 

pub struct TiltEstimatorConfig<const SAMPLES: usize> {
    pub correction_alpha: f32,
    pub integration_alpha: f32,
    pub use_gyro_integration: bool,
}
Configuration for a crate::TiltEstimator; the SAMPLES constant will determine how big a buffer of accelerometer readings to keep in order to compute the accelerometer’s average over time.

Fields

correction_alpha: f32

Value in [0..1] where 0 is purely accelerometer and 1 purely integrated gyro

integration_alpha: f32

Used to scale the gyro force strenght when integrating gyro values

use_gyro_integration: bool

Whether to integrate gyro values or only use accelerometer averages

Implementations

Source

impl<const SAMPLES: usize> TiltEstimatorConfig<SAMPLES>

pub fn new() -> TiltEstimatorConfig<SAMPLES>